@@ -3,6 +3,13 @@
 //! Unlike `HashMap` and [`crate::NEMap`], these feature a predictable iteration
 //! order.
 
+use crate::FromNonEmptyIterator;
+use crate::IntoNonEmptyIterator;
+use crate::NonEmptyIterator;
+use crate::Singleton;
+use indexmap::indexmap;
+use indexmap::Equivalent;
+use indexmap::IndexMap;
 use std::fmt;
 use std::fmt::Debug;
 use std::fmt::Formatter;
@@ -10,14 +17,6 @@ use std::hash::BuildHasher;
 use std::hash::Hash;
 use std::num::NonZeroUsize;
 
-use indexmap::indexmap;
-use indexmap::Equivalent;
-use indexmap::IndexMap;
-
-use crate::FromNonEmptyIterator;
-use crate::IntoNonEmptyIterator;
-use crate::NonEmptyIterator;
-
 /// Short-hand for constructing [`NEIndexMap`] values.
 ///
 /// ```
@@ -711,6 +710,32 @@ impl<K: Debug, V: Debug> Debug for ValuesMut<'_, K, V> {
     }
 }
 
+impl<K, V> Singleton for NEIndexMap<K, V>
+where
+    K: Eq + Hash,
+{
+    type Item = (K, V);
+
+    /// ```
+    /// use nonempty_collections::{NEIndexMap, Singleton, ne_indexmap};
+    ///
+    /// let m = NEIndexMap::singleton(('a', 1));
+    /// assert_eq!(ne_indexmap!['a' => 1], m);
+    /// ```
+    fn singleton((k, v): Self::Item) -> Self {
+        NEIndexMap::new(k, v)
+    }
+}
+
+impl<K, V> Extend<(K, V)> for NEIndexMap<K, V>
+where
+    K: Eq + Hash,
+{
+    fn extend<I: IntoIterator<Item = (K, V)>>(&mut self, iter: I) {
+        self.inner.extend(iter);
+    }
+}
+
 #[cfg(test)]
 mod test {
     use super::*;
