@@ -16,6 +16,7 @@ use crate::FromNonEmptyIterator;
 use crate::IntoIteratorExt;
 use crate::IntoNonEmptyIterator;
 use crate::NonEmptyIterator;
+use crate::Singleton;
 
 /// Like the [`crate::nev!`] macro, but for Maps. A nice short-hand for
 /// constructing [`NEMap`] values.
@@ -667,6 +668,32 @@ impl<K: fmt::Debug, V: fmt::Debug, S> fmt::Debug for NEMap<K, V, S> {
 //     }
 // }
 
+impl<K, V> Singleton for NEMap<K, V>
+where
+    K: Eq + Hash,
+{
+    type Item = (K, V);
+
+    /// ```
+    /// use nonempty_collections::{NEMap, Singleton, nem};
+    ///
+    /// let m = NEMap::singleton(('a', 1));
+    /// assert_eq!(nem!['a' => 1], m);
+    /// ```
+    fn singleton((k, v): Self::Item) -> Self {
+        NEMap::new(k, v)
+    }
+}
+
+impl<K, V> Extend<(K, V)> for NEMap<K, V>
+where
+    K: Eq + Hash,
+{
+    fn extend<I: IntoIterator<Item = (K, V)>>(&mut self, iter: I) {
+        self.inner.extend(iter);
+    }
+}
+
 #[cfg(test)]
 mod test {
     use std::num::NonZeroUsize;
