@@ -16,6 +16,7 @@ use crate::iter::NonEmptyIterator;
 use crate::FromNonEmptyIterator;
 use crate::IntoIteratorExt;
 use crate::IntoNonEmptyIterator;
+use crate::Singleton;
 
 /// Like the [`crate::nev!`] macro, but for Sets. A nice short-hand for
 /// constructing [`NESet`] values.
@@ -662,6 +663,32 @@ where
     }
 }
 
+impl<T> Singleton for NESet<T>
+where
+    T: Eq + Hash,
+{
+    type Item = T;
+
+    /// ```
+    /// use nonempty_collections::{NESet, Singleton, nes};
+    ///
+    /// let s = NESet::singleton(1);
+    /// assert_eq!(nes![1], s);
+    /// ```
+    fn singleton(item: Self::Item) -> Self {
+        NESet::new(item)
+    }
+}
+
+impl<T> Extend<T> for NESet<T>
+where
+    T: Eq + Hash,
+{
+    fn extend<I: IntoIterator<Item = T>>(&mut self, iter: I) {
+        self.inner.extend(iter);
+    }
+}
+
 #[cfg(test)]
 mod test {
     use maplit::hashset;
